@@ -1,8 +1,7 @@
-import datetime
 import json
 import time
 from collections import OrderedDict
-from copy import deepcopy
+from datetime import datetime
 
 from click import prompt, secho
 
@@ -18,9 +17,10 @@ from indico_install.utils import (
 )
 
 TRACKER_CONFIGMAP = "cluster-manager"
-TRACKER_CONFIGMAP_BACKUP = "cluster-manager-backup"
+TRACKER_CONFIGMAP_BACKUP = "cluster-manager-backup-"
 LOCK_TIMEOUT = 60  # seconds to wait for configmap lock
 UPDRAFT_BUCKET = "gs://indico-templates"
+TRACKER_BACKUP_LIMIT = 30
 
 
 """
@@ -63,20 +63,22 @@ def get_services_from_tag(updraft_tag):
     return results
 
 
-def _list_versions(grep):
-    grep = f" | grep {grep}" if grep else ""
-    out = run_cmd(f"gsutil ls -d {UPDRAFT_BUCKET}{grep}", silent=True).splitlines()
-    return [i[len(UPDRAFT_BUCKET):].replace('/', '') for i in out]
-
-
-def _list_versions_ordered(grep):
-    out = run_cmd(f"gsutil ls -l {UPDRAFT_BUCKET}/*{grep}*/services.yaml", silent=True).splitlines()[:-1]
+def _list_versions():
+    version = "IPA-[0-9]?[0-9]?[0-9]"
+    out = run_cmd(f"gsutil ls -d {UPDRAFT_BUCKET}/{version}", silent=True).splitlines()
     return [
-        f"{i[0]} " + i[1][len(UPDRAFT_BUCKET):-len("services.yaml")].replace('/', '') for i in
-        sorted([i.split()[1:] for i in out], key=lambda x: x[0], reverse=True)
+        i[len(UPDRAFT_BUCKET) :].replace("/", "") for i in sorted(out, reverse=True)
     ]
 
 
+def list_backups():
+    out = run_cmd(
+        "kubectl get cm --no-headers -o custom-columns=Name:.metadata.name 2>&1 "
+        "| grep {TRACKER_CONFIGMAP_BACKUP}",
+        silent=True,
+    )
+    return [] if not out else sorted(out.splitlines(), reverse=True)
+
 
 class ClusterManager(object):
     """
@@ -142,9 +144,15 @@ class ClusterManager(object):
             for svc, val in self.cluster_config["services"].items():
                 if "values" not in val:
                     continue
-                keys_to_migrate = [k for k in ("image", "updated_by", "updated_at") if k in val["values"]]
+                keys_to_migrate = [
+                    k
+                    for k in ("image", "updated_by", "updated_at")
+                    if k in val["values"]
+                ]
                 if keys_to_migrate:
-                    services[svc] = {"values": {k: val["values"].pop(k) for k in keys_to_migrate}}
+                    services[svc] = {
+                        "values": {k: val["values"].pop(k) for k in keys_to_migrate}
+                    }
 
                 # we don't want empty values floating around either
                 if not val["values"]:
@@ -153,21 +161,24 @@ class ClusterManager(object):
                     unneeded.append(svc)
             [self.cluster_config["services"].pop(svc) for svc in unneeded]
             updates["services"] = services
-        if "hash" in self.cluster_config["frontend"]:
-            updates["frontend"] = {"hash": self.cluster_config["frontend"].pop("hash")}
+        fe_config = self.cluster_config.get("frontend", {})
+        updates["frontend"] = {
+            k: self.cluster_config["frontend"].pop(k)
+            for k in ("hash", "updated_by", "updated_at")
+            if k in fe_config
+        }
         return updates
 
     @classmethod
-    def get_updraft_versions(cls, regex, number, ordered):
-        regex = string_to_tag(regex)
-        res_list = _list_versions_ordered(regex) if ordered else _list_versions(regex)
+    def get_updraft_versions(cls, number):
+        res_list = _list_versions()
         return res_list[:number] if number else res_list
 
-    def load_from_cluster(self, backup=False):
+    def load_from_cluster(self, backup_conf: str = None):
         """
         Use the version configmap on the cluster to populate this Tracker instance
         """
-        conf = TRACKER_CONFIGMAP_BACKUP if backup else TRACKER_CONFIGMAP
+        conf = backup_conf if backup_conf else TRACKER_CONFIGMAP
         known_info = load_from_configmap(conf, data_parser=json.loads)
         if known_info:
             known_info = known_info["data"]
@@ -183,7 +194,9 @@ class ClusterManager(object):
         Take a patch for cluster config and apply
         """
         if changes:
-            self.cluster_config = changes if replace else merge_dicts(self.cluster_config, changes)
+            self.cluster_config = (
+                changes if replace else merge_dicts(self.cluster_config, changes)
+            )
         if version:
             self.indico_version = version
 
@@ -234,7 +247,10 @@ class ClusterManager(object):
             raise TimeoutError("Lock was not acquired. Please try again later")
 
         self._lock = time.time()
-        run_cmd(f"kubectl label cm {TRACKER_CONFIGMAP} lock={self._lock}", silent=True)
+        run_cmd(
+            f"kubectl label cm {TRACKER_CONFIGMAP} lock={self._lock} --overwrite",
+            silent=True,
+        )
         if needed_to_wait:
             self.load_from_cluster()
         return self._lock
@@ -294,15 +310,17 @@ class ClusterManager(object):
             return
         changes = {}
         curr_user = current_user()
-        curr_time = str(datetime.datetime.now())
+        curr_time = str(datetime.now())
         if state:
             changes["services"] = OrderedDict(
                 {
-                    k: {"values": {
-                        "image": v.replace(self.registry, ""),
-                        "updated_by": curr_user,
-                        "updated_at": curr_time,
-                    }}
+                    k: {
+                        "values": {
+                            "image": v.replace(self.registry, ""),
+                            "updated_by": curr_user,
+                            "updated_at": curr_time,
+                        }
+                    }
                     for k, v in sorted(state.items())
                 }
             )
@@ -330,7 +348,10 @@ class ClusterManager(object):
             "apiVersion": "v1",
             "kind": "ConfigMap",
             "metadata": {
-                "name": TRACKER_CONFIGMAP_BACKUP if backup else TRACKER_CONFIGMAP,
+                "name": TRACKER_CONFIGMAP_BACKUP
+                + datetime.today().strftime("%Y%m%d-%H%M")
+                if backup
+                else TRACKER_CONFIGMAP
             },
             "data": OrderedDict({k: json.dumps(v) for k, v in self.to_dict().items()}),
         }
@@ -347,6 +368,9 @@ class ClusterManager(object):
             f"echo '{json.dumps(self.to_configmap(backup=backup))}' | kubectl apply -f -",
             silent=True,
         )
+        if backup:
+            for bk_cm in list_backups()[TRACKER_BACKUP_LIMIT:]:
+                run_cmd(f"kubectl delete cm {bk_cm} 2>&1", silent=True)
 
     def diff_version(self, tag=None):
         tag = tag or self.indico_version
