@@ -65,7 +65,15 @@ def find_dependent_services(updated_services: list) -> set:
     help="Restart services affected by updated configmap or secrets",
 )
 @options_wrapper()
-def apply(ctx, restart_deps=True, service=None, deployment_root=None, yes=False, cluster_manager=None, **kwargs):
+def apply(
+    ctx,
+    restart_deps=True,
+    service=None,
+    deployment_root=None,
+    yes=False,
+    cluster_manager=None,
+    **kwargs,
+):
     """
     Apply templates in the "generated/" directory.
     Apply only the template files matching <SERVICE> if provided.
@@ -123,7 +131,9 @@ def apply(ctx, restart_deps=True, service=None, deployment_root=None, yes=False,
     # And save information with the version cluster_manager
     if updated_services:
         cluster_manager = cluster_manager or ClusterManager()
-        cluster_manager.update_from_current([s.split("/", 1)[-1] for s in updated_services])
+        cluster_manager.update_from_current(
+            [s.split("/", 1)[-1] for s in updated_services]
+        )
         updated_confs = [
             ups
             for ups in updated_services
@@ -142,4 +152,6 @@ def apply(ctx, restart_deps=True, service=None, deployment_root=None, yes=False,
             for dep_service in dependent_services:
                 ctx.invoke(restart, service=dep_service, contains=False, wait="2m")
         else:
-            click.secho(f"{', '.join(updated_confs)} were updated. Make sure to restart dependent services")
+            click.secho(
+                f"{', '.join(updated_confs)} were updated. Make sure to restart dependent services"
+            )
