@@ -19,7 +19,7 @@ NODE_POOL_TYPES = {
         "accelerator": "type=nvidia-tesla-p4,count=1",
     },
     # N2s do not support GPU and are not supported in us-east4-c
-    "default-cpu-pool": {"machine-type": "n1-standard-2"},
+    "default-cpu-pool": {"machine-type": "c2-standard-4"},
     "default-mem-pool": {"machine-type": "n1-standard-8"},
     "default-pool": {"machine-type": "n1-standard-8"},
     "default-pvm-pool": {
@@ -27,10 +27,9 @@ NODE_POOL_TYPES = {
         "preemptible": None,
         "max-nodes": 6,
     },
-    "default-pvm-gpu-pool": {
-        "machine-type": "n1-standard-8",
-        "preemptible": None,
-        "accelerator": "type=nvidia-tesla-p4,count=1",
+    "t4-gpu-pool": {
+        "machine-type": "n1-highmem-4",
+        "accelerator": "type=nvidia-tesla-t4,count=1",
     },
 }
 
@@ -43,11 +42,12 @@ autoscale_option = click.option(
 )
 
 
-def nodegroup_args(ng_type, count, **kwargs):
+def nodegroup_args(ng_type, count, pvm=False, **kwargs):
     count = int(count)
     args = merge_dicts(DEFAULT_NODE_CONFIGS, NODE_POOL_TYPES[ng_type])
     args.update(kwargs)
-
+    if pvm:
+        args["preemptible"] = None  # Add as flag
     max_nodes = args.get("max-nodes", count)
     args["max-nodes"] = max_nodes if count < max_nodes else count + 1
     if args.pop("autoscale", True):
@@ -65,7 +65,22 @@ def gke(ctx):
 
 
 gke.command("init")(init(__name__))
-environment_abbrev = {"production": "prod", "development": "dev"}
+environment_abbrev = {"production": "prod", "development": "dev", "staging": "stage"}
+environment_colors = {"production": "red", "development": "green", "staging": "blue"}
+environment_subnets = {
+    "production": {
+        "us-central1-f": "production-central1",
+        "us-east4-c": "production-east4",
+    },
+    "staging": {
+        "us-central1-f": "production-central1",
+        "us-east4-c": "production-east4",
+    },
+    "development": {
+        "us-central1-f": "development-central1",
+        "us-east4-c": "development-default",
+    },
+}
 
 
 @gke.command("create-nodepools")
@@ -78,8 +93,11 @@ environment_abbrev = {"production": "prod", "development": "dev"}
     help=f"additional pools and counts. EX: --node-pool gpu=3 --node-pool finetune=1. Types are {list(NODE_POOL_TYPES.keys())}",
     multiple=True,
 )
+@click.option("--pvm", help=f"enable preemptible nodes", is_flag=True)
 @autoscale_option
-def create_nodepools(ctx, cluster_name, autoscale=True, node_pool=None):
+def create_nodepools(
+    ctx, cluster_name, autoscale=True, node_pool=None, pvm: bool = False
+):
     """
     Creates additional nodepools for existing cluster
     """
@@ -100,8 +118,9 @@ def create_nodepools(ctx, cluster_name, autoscale=True, node_pool=None):
     for np, count in node_pools.items():
         count = int(count)
         run_cmd(
-            f"gcloud container node-pools create {np} "
-            f"--num-nodes={count} --cluster={cluster_name} " + nodegroup_args(np, count)
+            f"gcloud container node-pools create {np}{'-pvm' if pvm else ''} "
+            f"--num-nodes={count} --cluster={cluster_name} "
+            + nodegroup_args(np, count, pvm)
         )
 
 
@@ -112,7 +131,7 @@ def create_nodepools(ctx, cluster_name, autoscale=True, node_pool=None):
 @click.argument("size", type=int)
 @click.option("--subnetwork", help="Network to be used")
 @click.option(
-    "--version", help="GKE Cluster Version", default="1.14.8-gke.33", show_default=True
+    "--version", help="GKE Cluster Version", default="1.15.11-gke.3", show_default=True
 )
 @click.option(
     "--project", help="GKE Project Name", default="new-indico", show_default=True
@@ -166,7 +185,11 @@ def create_cluster(
     Development scaling is: default-pool=1, default-gpu-pool=1, default-pvm-pool=1
     """
     environment = next(
-        iter(env for env in {"production", "development"} if environment in env)
+        iter(
+            env
+            for env in {"production", "development", "staging"}
+            if environment in env
+        )
     )
 
     name = name.lower()
@@ -175,13 +198,15 @@ def create_cluster(
     size = int(size)
     assert size > 0
 
-    subnetwork = subnetwork or f"{environment}-default"
-    network = f"indico-{environment}"
+    subnetwork = subnetwork or environment_subnets[environment][zone]
+    network = (
+        f"indico-production" if environment is "staging" else f"indico-{environment}"
+    )
     optimization_profile = "optimize-utilization" if optimize else "balanced"
 
     click.secho(
         f"Creating cluster {name} in {environment} with {size} nodes...",
-        fg="red" if environment == "production" else "green",
+        fg=environment_colors[environment],
     )
     # TODO: Check if we need the python2.7 aliasing.
     # If we do, figure out how to install gcloud for python3
@@ -196,8 +221,7 @@ def create_cluster(
             --username "admin" \
             --cluster-version "{version}" \
             --num-nodes "{size}" \
-            --enable-cloud-logging \
-            --enable-cloud-monitoring \
+            --enable-stackdriver-kubernetes \
             --addons HorizontalPodAutoscaling,HttpLoadBalancing \
             --no-enable-autoupgrade \
             --enable-ip-alias \
